@@ -3,10 +3,16 @@ from pathlib import Path
 from pg_data_etl import helpers
 
 
-def dump(self, output_folder: str) -> Path:
+def dump(self, output_folder: str = ".") -> Path:
     """
     - Create a standalone text file backup of the entire database.
     - Returns the full filepath to the newly created file.
+
+    Arguments:
+        output_folder (str): folder where output file should go. Defaults to active directory.
+
+    Returns:
+        Path: to the newly created output file
     """
 
     db_name = self.connection_params["db_name"]
