@@ -1,14 +1,19 @@
+from __future__ import annotations
 from pathlib import Path
 
 from pg_data_etl import helpers
 
 
-def load_from_dumpfile(self, filepath: str) -> None:
+def load_from_dumpfile(self, filepath: str | Path) -> None:
     """
     - Load a `.sql` file into a new database
+    - The database must not already exist
 
-    Args:
+    Arguments:
         filepath (str): full path to the SQL file
+
+    Returns:
+        loads the `.sql` file into an empty database
     """
 
     db_name = self.connection_params["db_name"]
@@ -17,4 +22,6 @@ def load_from_dumpfile(self, filepath: str) -> None:
         print(f"Database {db_name} already exists. Use a different name.")
     else:
         command = f'"{self.cmd.psql}" -f "{filepath}" {self.uri}'
-        helpers.run_command_in_shell(command)
\ No newline at end of file
+        helpers.run_command_in_shell(command)
+
+    return None
